aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorberat <beratiz@gmail.com>2017-09-22 19:00:27 +0200
committerberat <beratiz@gmail.com>2017-09-22 19:00:27 +0200
commitf575959cd2ccfda1c1375624cec80e1c9a92f5b0 (patch)
tree6b365f10a7fc1dfbf9e0c19c2efc1f77ab18b67d
parentc2002cd48f5a8cbc7d806350a3543960c00a3579 (diff)
typos and renames
-rw-r--r--example/ndpiReader.c30
-rw-r--r--example/ndpi_util.h4
2 files changed, 17 insertions, 17 deletions
diff --git a/example/ndpi_util.h b/example/ndpi_util.h
index 5fe3dc66b..fd4c4b84d 100644
--- a/example/ndpi_util.h
+++ b/example/ndpi_util.h
@@ -46,8 +46,8 @@
#define DIR_DST 20
#define PORT_ARRAY_SIZE 20
#define HOST_ARRAY_SIZE 20
-#define FLOWS_PACKETS_TRESHOLD 0.9
-#define FLOWS_PERCENT_TRESHOLD 1.0
+#define FLOWS_PACKETS_THRESHOLD 0.9
+#define FLOWS_PERCENT_THRESHOLD 1.0
#define INIT_VAL -1
// flow tracking
diff --git a/example/ndpiReader.c b/example/ndpiReader.c
index 9def14de1..218f251c3 100644
--- a/example/ndpiReader.c
+++ b/example/ndpiReader.c
@@ -1502,7 +1502,7 @@ static void saveScannerStats(json_object **jObj_group, struct single_flow_info *
if(j >= 10) break;
}
- json_object_object_add(jObj_stat,"top.ports",jArray_ports);
+ json_object_object_add(jObj_stat,"top.dst.ports",jArray_ports);
json_object_array_add(jArray_stats, jObj_stat);
j = 0;
@@ -1510,7 +1510,7 @@ static void saveScannerStats(json_object **jObj_group, struct single_flow_info *
if(i >= 10) break;
}
- json_object_object_add(*jObj_group, "scanner.stats", jArray_stats);
+ json_object_object_add(*jObj_group, "top.scanner.stats", jArray_stats);
}
@@ -1545,8 +1545,8 @@ static void saveTopStats(json_object **jObj_group,
json_object_new_double(((double)s->num_flows)/s->num_pkts));
else json_object_object_add(jObj_stat,"flows.num_packets",json_object_new_double(0.0));
- json_object_object_add(jObj_stat,"aggressive.ip",json_object_new_string(s->top_ip));
- json_object_object_add(jObj_stat,"protocol",json_object_new_string(s->proto));
+ json_object_object_add(jObj_stat,"aggressive.host",json_object_new_string(s->top_ip));
+ json_object_object_add(jObj_stat,"host.app.protocol",json_object_new_string(s->proto));
json_object_array_add(jArray_stats, jObj_stat);
i++;
@@ -1569,8 +1569,8 @@ static void saveTopStats(json_object **jObj_group,
json_object *jObj_stat = json_object_new_object();
json_object_object_add(jObj_stat,"port",json_object_new_int(s->port));
- json_object_object_add(jObj_stat,"ip.total",json_object_new_int64(s->num_addr));
- json_object_object_add(jObj_stat,"ip.percent",json_object_new_double((s->num_addr*100.0)/total_ip_addr));
+ json_object_object_add(jObj_stat,"host.number",json_object_new_int64(s->num_addr));
+ json_object_object_add(jObj_stat,"host.percent",json_object_new_double((s->num_addr*100.0)/total_ip_addr));
json_object_object_add(jObj_stat,"flows.number",json_object_new_double(s->num_flows));
json_object_array_add(jArray_stats,jObj_stat);
@@ -1580,7 +1580,7 @@ static void saveTopStats(json_object **jObj_group,
}
json_object_object_add(*jObj_group, (direction == DIR_SRC) ?
- "top.src.ip.stats" : "top.dst.ip.stats", jArray_stats);
+ "top.src.host.stats" : "top.dst.host.stats", jArray_stats);
}
#endif
@@ -2500,7 +2500,7 @@ void bpf_filter_port_array_add(int filter_array[], int size, int port) {
/* *********************************************** */
/*
* @brief add ports which have (flows/packets > treshold)
* and have (#flows > %1 of total flows) to the srcPortArray
* to filter
*/
@@ -2529,7 +2529,7 @@ void getPacketBasedSourcePortsToFilter(struct json_object *jObj_stat, int srcPor
double flows_packets = json_object_get_double(jObj_flows_packets);
- if((flows_packets > FLOWS_PACKETS_TRESHOLD) && (flows_percent >= FLOWS_PERCENT_TRESHOLD)) {
+ if((flows_packets > FLOWS_PACKETS_THRESHOLD) && (flows_percent >= FLOWS_PERCENT_THRESHOLD)) {
if((res = json_object_object_get_ex(src_pkts_stat, "port", &jObj_port)) == 0) {
fprintf(stderr, "ERROR: can't get \"port\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
exit(-1);
@@ -2602,8 +2602,8 @@ void getTopReceiverHostsToFilter(struct json_object *jObj_stat, int duration, co
if(flows_percent > 0.2) {
- if((res = json_object_object_get_ex(scanner_stat, "aggressive.ip", &jObj_host_address)) == 0) {
- fprintf(stderr, "ERROR: can't get \"aggressive.ip\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
+ if((res = json_object_object_get_ex(scanner_stat, "aggressive.host", &jObj_host_address)) == 0) {
+ fprintf(stderr, "ERROR: can't get \"aggressive.host\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
exit(-1);
}
const char *host_address = json_object_get_string(jObj_host_address);
@@ -2719,8 +2719,8 @@ static void produceBpfFilter(char *filePath) {
json_object *stats = json_object_array_get_idx(jObj_statistics, i);
json_object *val;
- if((res = json_object_object_get_ex(stats, "scanner.stats", &val)) == 0) {
- fprintf(stderr,"ERROR: can't get \"scanner.stats\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
+ if((res = json_object_object_get_ex(stats, "top.scanner.stats", &val)) == 0) {
+ fprintf(stderr,"ERROR: can't get \"top.scanner.stats\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
exit(-1);
}
getScannerHostsToFilter(val, duration, filterSrcHosts, HOST_ARRAY_SIZE);
@@ -2733,8 +2733,8 @@ static void produceBpfFilter(char *filePath) {
getPacketBasedSourcePortsToFilter(val, filterSrcPorts, PORT_ARRAY_SIZE);
- if((res = json_object_object_get_ex(stats, "top.src.ip.stats", &val)) == 0) {
- fprintf(stderr,"ERROR: can't get \"top.src.ip.stats\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
+ if((res = json_object_object_get_ex(stats, "top.src.host.stats", &val)) == 0) {
+ fprintf(stderr,"ERROR: can't get \"top.src.host.stats\", use -x flag only with .json files generated by ndpiReader -b flag.\n");
exit(-1);
}
getHostBasedSourcePortsToFilter(val, duration, filterSrcPorts, PORT_ARRAY_SIZE);
@@ -2500,7 +2500,7 @@ void bpf_filter_port_array_add(int filter_array[], int size, int port) {
/* *********************************************** */
/*
- * @brief add ports which have (flows/packets > treshold)
+ * @brief add ports which have (flows/packets > threshold)
* and have (#flows > %1 of total flows) to the srcPortArray
* to filter